@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base 'Text::MicroTemplate::File';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub new {
     my $self = shift->SUPER::new(@_);
@@ -353,7 +353,7 @@ C<template_args> also supports CodeRef as its value life below:
         ...
     );
 
-In template, you can C<<?= $foo ?>> to show C<$foo> value. this value is set by calling C<$self->get_foo> in template process time.
+In template, you can C<<?= $foo ?>> to show C<$foo> value. this value is set by calling C<< $self->get_foo >> in template process time.
 
 This feature is useful to set variable does not exists when template object is created.
 
